////! By convention, main.zig is where your main function lives in the case that
////! you are building an executable. If you are making a library, the convention
////! is to delete this file and start with root.zig instead.

//pub fn main() !void {
//    // Prints to stderr (it's a shortcut based on `std.io.getStdErr()`)
//    std.debug.print("All your {s} are belong to us.\n", .{"codebase"});

//    // stdout is for the actual output of your application, for example if you
//    // are implementing gzip, then only the compressed bytes should be sent to
//    // stdout, not any debugging messages.
//    const stdout_file = std.io.getStdOut().writer();
//    var bw = std.io.bufferedWriter(stdout_file);
//    const stdout = bw.writer();

//    try stdout.print("Run `zig build test` to run the tests.\n", .{});

//    try bw.flush(); // Don't forget to flush!
//}

//test "simple test" {
//    var list = std.ArrayList(i32).init(std.testing.allocator);
//    defer list.deinit(); // Try commenting this out and see if zig detects the memory leak!
//    try list.append(42);
//    try std.testing.expectEqual(@as(i32, 42), list.pop());
//}

//test "use other module" {
//    try std.testing.expectEqual(@as(i32, 150), lib.add(100, 50));
//}

//test "fuzz example" {
//    const Context = struct {
//        fn testOne(context: @This(), input: []const u8) anyerror!void {
//            _ = context;
//            // Try passing `--fuzz` to `zig build test` and see if it manages to fail this test case!
//            try std.testing.expect(!std.mem.eql(u8, "canyoufindme", input));
//        }
//    };
//    try std.testing.fuzz(Context{}, Context.testOne, .{});
//}

//const std = @import("std");

///// This imports the separate module containing `root.zig`. Take a look in `build.zig` for details.
//const lib = @import("homepage_lib");

const std = @import("std");
const zap = @import("zap");

fn on_request(r: zap.Request) void {
    if (r.path) |the_path| {
        std.debug.print("PATH: {s}\n", .{the_path});
    }

    if (r.query) |the_query| {
        std.debug.print("QUERY: {s}\n", .{the_query});
    }
    r.sendBody("<html><body><h1>Hello from ZAP!!!</h1></body></html>") catch return;
}

pub fn main() !void {
    var listener = zap.HttpListener.init(.{
        .port = 3000,
        .on_request = on_request,
        .log = true,
    });
    try listener.listen();

    std.debug.print("Listening on 0.0.0.0:3000\n", .{});

    // start worker threads
    zap.start(.{
        .threads = 2,
        .workers = 2,
    });
}
